summaryrefslogtreecommitdiffstats
path: root/lib/backgroundjob.php
diff options
context:
space:
mode:
authorJakob Sack <mail@jakobsack.de>2012-10-27 10:15:39 +0200
committerJakob Sack <mail@jakobsack.de>2012-10-27 10:15:39 +0200
commitd0bbd9416b036e4d89599b8c44b2110743264508 (patch)
tree04a676788be1d65adc8ac28282be8cf5d429b588 /lib/backgroundjob.php
parentf5f204de56ce93c7fd12941951cf99a24f5bf8b1 (diff)
downloadnextcloud-server-d0bbd9416b036e4d89599b8c44b2110743264508.tar.gz
nextcloud-server-d0bbd9416b036e4d89599b8c44b2110743264508.zip
Add BackgroundJob::setExecutionType() to public API
Diffstat (limited to 'lib/backgroundjob.php')
-rw-r--r--lib/backgroundjob.php14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/backgroundjob.php b/lib/backgroundjob.php
index 992a2484ea5..6415f5b84aa 100644
--- a/lib/backgroundjob.php
+++ b/lib/backgroundjob.php
@@ -25,25 +25,25 @@
*/
class OC_BackgroundJob{
/**
* @brief get the type of background jobs
* @return string
*
* This method returns the type how background jobs are executed. If the user
* did not select something, the type is ajax.
*/
- public static function getType() {
+ public static function getExecutionType() {
return OC_Appconfig::getValue( 'core', 'backgroundjobs_mode', 'ajax' );
}
/**
* @brief sets the background jobs type
* @param $type type of background jobs
* @return boolean
*
* This method sets the type of the background jobs. Possible types are
* "none", "ajax", "webcron", "cron"
*/
- public static function setType( $type ) {
+ public static function setExecutionType( $type ) {
if( !in_array( $type, array('none', 'ajax', 'webcron', 'cron'))){
return false;
}
@@ -25,25 +25,25 @@
class OC_BackgroundJob{
/**
- * @brief get the type of background jobs
+ * @brief get the execution type of background jobs
* @return string
*
@@ -25,25 +25,25 @@
}
/**
- * @brief sets the background jobs type
- * @param $type type of background jobs
+ * @brief sets the background jobs execution type
+ * @param $type execution type
* @return boolean
*
@@ -25,25 +25,25 @@
* @return boolean
*
- * This method sets the type of the background jobs. Possible types are
- * "none", "ajax", "webcron", "cron"
+ * This method sets the execution type of the background jobs. Possible types
+ * are "none", "ajax", "webcron", "cron"
*/